@@ -167,6 +167,8 @@ class MathStructure {
 		ComparisonType ct_comp;
 		bool b_protected;
 		
+		bool b_parentheses;
+		
 		bool isolate_x_sub(const EvaluationOptions &eo, EvaluationOptions &eo2, const MathStructure &x_var, MathStructure *morig = NULL);
 		void init();
 	
@@ -843,7 +845,8 @@ class MathStructure {
 		/** @name Functions for polynomials */
 		//@{
 		bool simplify(const EvaluationOptions &eo = default_evaluation_options, bool unfactorize = true);
-		bool factorize(const EvaluationOptions &eo = default_evaluation_options, bool unfactorize = true, int term_combination_levels = 0, int max_msecs = 1000, bool only_integers = true, int recursive = 1, struct timeval *endtime_p = NULL, const MathStructure &force_factorization = m_undefined, bool complete_square = false, bool only_sqrfree = false);
+		bool factorize(const EvaluationOptions &eo = default_evaluation_options, bool unfactorize = true, int term_combination_levels = 0, int max_msecs = 1000, bool only_integers = true, int recursive = 1, struct timeval *endtime_p = NULL, const MathStructure &force_factorization = m_undefined, bool complete_square = false, bool only_sqrfree = false, int max_degree_factor = -1);
+		bool expandPartialFractions(const EvaluationOptions &eo);
 		bool structure(StructuringMode structuring, const EvaluationOptions &eo, bool restore_first = true);
 		/** If the structure represents a rational polynomial.
 		* This is true for
@@ -870,6 +873,12 @@ class MathStructure {
 		void polynomialUnitContentPrimpart(const MathStructure &xvar, int &munit, MathStructure &mcontent, MathStructure &mprim, const EvaluationOptions &eo) const;
 		//@}
 		
+		/** @name Functions for conversion of complex numbers */
+		//@{
+		bool complexToExponentialForm(const EvaluationOptions &eo);
+		bool complexToPolarForm(const EvaluationOptions &eo);
+		//@}
+		
 		bool calculateLimit(const MathStructure &x_var, const MathStructure &limit, const EvaluationOptions &eo_pre, int approach_direction = 0);
 
 		bool decomposeFractions(const MathStructure &x_var, const EvaluationOptions &eo);
@@ -886,6 +895,9 @@ class MathStructure {
 		bool isolate_x(const EvaluationOptions &eo, const EvaluationOptions &feo, const MathStructure &x_var = m_undefined, bool check_result = false);
 		//@}
 		
+		bool inParentheses() const;
+		void setInParentheses(bool b = true);
+
 };
 
 ostream& operator << (ostream &os, const MathStructure&);
